Where to find things - WeeWX 5.0
Author: Tom Keffer <tkeffer@gmail.com>

Skip to content

# Where to find things

## Location of WeeWX components

Here is a summary of the layout for the different install methods, along with the symbolic names used for each component. These names are used throughout the documentation.

Debian RedHat openSUSE pip

Component | Symbolic name | Nominal value
--- | --- | ---
WeeWX root directory | `WEEWX_ROOT` | `/`
Executables | `BIN_ROOT` | `/usr/share/weewx/`
Configuration directory | `CONFIG_ROOT` | `/etc/weewx/`
Skins and templates | `SKIN_ROOT` | `/etc/weewx/skins/`
SQLite databases | `SQLITE_ROOT` | `/var/lib/weewx/`
Web pages and images | `HTML_ROOT` | `/var/www/html/weewx/`
Documentation | `DOC_ROOT` | `/usr/share/doc/weewx/`
Examples | `EXAMPLE_ROOT` | `/usr/share/doc/weewx/examples/`
User directory | `USER_ROOT` | `/usr/share/weewx/user/`

Component | Symbolic name | Nominal value
--- | --- | ---
WeeWX root directory | `WEEWX_ROOT` | `/`
Executables | `BIN_ROOT` | `/usr/share/weewx/`
Configuration directory | `CONFIG_ROOT` | `/etc/weewx/`
Skins and templates | `SKIN_ROOT` | `/etc/weewx/skins/`
SQLite databases | `SQLITE_ROOT` | `/var/lib/weewx/`
Web pages and images | `HTML_ROOT` | `/var/www/html/weewx/`
Documentation | `DOC_ROOT` | `/usr/share/doc/weewx-x.y.z/`
Examples | `EXAMPLE_ROOT` | `/usr/share/doc/weewx-x.y.z/examples/`
User directory | `USER_ROOT` | `/usr/share/weewx/user/`

Component | Symbolic name | Nominal value
--- | --- | ---
WeeWX root directory | `WEEWX_ROOT` | `/`
Executables | `BIN_ROOT` | `/usr/share/weewx/`
Configuration directory | `CONFIG_ROOT` | `/etc/weewx/`
Skins and templates | `SKIN_ROOT` | `/etc/weewx/skins/`
SQLite databases | `SQLITE_ROOT` | `/var/lib/weewx/`
Web pages and images | `HTML_ROOT` | `/var/www/html/weewx/`
Documentation | `DOC_ROOT` | `/usr/share/doc/weewx-x.y.z/`
Examples | `EXAMPLE_ROOT` | `/usr/share/doc/weewx-x.y.z/examples/`
User directory | `USER_ROOT` | `/usr/share/weewx/user/`

Component | Symbolic name | Nominal value
--- | --- | ---
WeeWX root directory | `WEEWX_ROOT` | `~/weewx-data`
Executables | `BIN_ROOT` | varies
Configuration directory | `CONFIG_ROOT` | `./`
Skins and templates | `SKIN_ROOT` | `skins/`
SQLite databases | `SQLITE_ROOT` | `archive/`
Web pages and images | `HTML_ROOT` | `public_html/`
Documentation | `DOC_ROOT` | `docs/`
Examples | `EXAMPLE_ROOT` | `examples/`
User directory | `USER_ROOT` | `bin/user/`

Note

In the locations above, relative paths are relative to `WEEWX_ROOT`. Absolute paths begin with a forward slash (`/`).

## Location of executables in a pip install

If you use a pip install, the location of the executables will depend on how the pip installation was done.

Install method | Commands | Location of executables
--- | --- | ---
Virtual environment (recommended) | `python3 -m venv ~/ve` `source ~/ve/bin/activate` `pip3 install weewx` | `~/ve/bin/`
pip, no sudo, with `--user` | `pip3 install weewx --user` | `~/.local/bin/`
pip, no sudo, no `--user` | `pip3 install weewx` | `~/.local/bin/`
pip with sudo (not recommended) | `sudo pip3 install weewx` | `/usr/local/bin/` (1)
Virtual environment with `--user` | `python3 -m venv ~/ve` `source ~/ve/bin/activate` `pip3 install weewx --user` | Not allowed

(1) Checked on Ubuntu 22.02 and Rocky v9.1

## Log files

In the default configuration, WeeWX writes its status to the system log. This is where to find the system log for each platform.

Debian RedHat openSUSE macOS

`/var/log/syslog`

Note

You need root permission to view the log.

`/var/log/messages`

Note

You need root permission to view the log.

`/var/log/messages`

Note

You need root permission to view the log.

`/var/log/syslog`

Note

On macOS, the log file is likely to contain only severe log messages.

If the default for your system is inconvenient, or does not provide the logging fidelity that you require, then you may want to consider logging to a separate, rotating log file. See the wiki article Logging to rotating files.